[![Test](https://github.com/maukoquiroga/mantic/workflows/test/badge.svg)](https://github.com/maukoquiroga/mantic/actions?workflow=test)
[![Type](https://github.com/maukoquiroga/mantic/workflows/type/badge.svg)](https://github.com/maukoquiroga/mantic/actions?workflow=type)
[![Lint](https://github.com/maukoquiroga/mantic/workflows/lint/badge.svg)](https://github.com/maukoquiroga/mantic/actions?workflow=lint)
[![Docs](https://github.com/maukoquiroga/mantic/workflows/docs/badge.svg)](https://github.com/maukoquiroga/mantic/actions?workflow=docs)
[![Docs](https://readthedocs.org/projects/mantic/badge/)](https://mantic.readthedocs.io/)
[![PyPI](https://img.shields.io/pypi/v/mantic.svg)](https://pypi.org/project/mantic/)
[![Coverage](https://codecov.io/gh/maukoquiroga/mantic/branch/main/graph/badge.svg)](https://codecov.io/gh/maukoquiroga/mantic)

# Mantic

Command-line tools to facilitate se-mantic versioning!

## Demo

![mantic](https://user-images.githubusercontent.com/329236/137640522-1673fc7e-8d88-4418-b10a-29e1e4a1408a.gif)

## Installation

```
pip install mantic
```

## Usage

```
mantic --help
mantic --help check-version
mantic check-version
```

## License

Copyleft (ɔ) 2021 Mauko Quiroga <mauko@pm.me>

Licensed under the EUPL-1.2-or-later
For details: [https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12](https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12)
